import java.sql.*;
import java.util.Vector;
import java.util.Iterator;

public class POQExplorateur
{
   private static final String
      URI_SOURCE = "jdbc:odbc:POQ"
,     CLASSE_PILOTE = "sun.jdbc.odbc.JdbcOdbcDriver"
;
   private Connection m_Connexion;

   public POQExplorateur ()
   {
      m_Connexion = null;
   }

   // Mthode CrerConnexion ()
   //
   // Cre une connexion  la BD. Retourne VRAI (true) dans le cas
   // d'un succs et FAUX (false) dans le cas d'un chec
   //
   // Cas d'exception possibles
   // -- classe pilote introuvable (erreur sur Class.forName ())
   // -- erreur SQL (ex: BD absente)
   public boolean CrerConnexion ()
   {
      boolean ConnexionOuverte = false;
      try
      {
         // -- Charger la classe pilote
         Class.forName (CLASSE_PILOTE);
         m_Connexion = DriverManager.getConnection (URI_SOURCE);
         ConnexionOuverte = true;
      }
      catch (ClassNotFoundException cnfe)
      {
         System.err.println (cnfe.getMessage ());
      }
      catch (SQLException sqle)
      {
         System.err.println (sqle.getMessage ());
      }
      return ConnexionOuverte;
   }

   // Mthode GetListePropritaires ()
   //
   // Extrait la liste des noms de propritaires, les insre dans
   // un vecteur (tableau dynamique) et retourne ce vecteur
   public Vector GetListePropritaires ()
   {
      final String SQL_LISTE_PROPRITAIRES =
         "Select NomProprio From POQProprio";

      Vector v = new Vector ();
      try
      {
         Statement stmt = m_Connexion.createStatement ();
         ResultSet results = stmt.executeQuery (SQL_LISTE_PROPRITAIRES);
         while (results.next ())
            v.add (results.getString ("NomProprio"));
         results.close ();
      }
      catch (SQLException sqle)
      {
         System.err.println (sqle.getMessage ());
      }
      return v;
   }

   // Mthode FermerConnexion ()
   //
   // Ferme la connexion  la BD (si elle est ouverte)
   //
   // Cas d'exception possibles
   // -- erreur SQL (ex: BD pas ouverte)
   public void FermerConnexion ()
   {
      if (m_Connexion != null)
      {
         try
         {
            m_Connexion.close ();
         }
         catch (SQLException sqle)
         {
            System.err.println (sqle.getMessage ());
         }
         m_Connexion = null; // pour simplifier la collecte d'ordures
      }
   }

   // Programme principal
   //
   // Ouvre une connexion  la BD; en extrait la liste des propritaires
   // de POQmon (leur nom seulement); affiche cette liste; puis ferme la
   // connexion
   public static void main (String [] args)
   {
      POQExplorateur pe = new POQExplorateur();
      if (pe.CrerConnexion ())
      {
         Vector v = pe.GetListePropritaires ();
         Iterator itt = v.iterator ();
         System.out.println ("Liste des propritaires de POQmon:");
         while (itt.hasNext ())
            System.out.println ((String) itt.next ());
         pe.FermerConnexion ();
      }
   }
}
