import java.sql.*;
import java.util.Vector;
import java.util.Iterator;

public class POQExplorateur_v2
{
   private static class Connexion
   {
      private static final String
         URI_SOURCE = "jdbc:odbc:POQ",
         CLASSE_PILOTE = "sun.jdbc.odbc.JdbcOdbcDriver";

      private boolean m_ConnexionOuverte;
      private Connection m_Connexion;

      private static Connexion Singleton = null;
      private int m_NbUsagers;
      public static Connexion GetConnexion ()
      {
         if (Singleton == null)
            Singleton = new Connexion ();
         Singleton.AjouterRfrence ();
         return Singleton;
      }
      public void RelcherConnexion ()
      {
         m_NbUsagers --;
         if (m_NbUsagers == 0)
         {
            Terminer ();
            Singleton = null;
         }
      }
      private void AjouterRfrence ()
      {
         m_NbUsagers ++;
      }
      // Mthode Terminer()
      //
      // Ferme la connexion  la BD (si elle est ouverte)
      //
      // Cas d'exception possibles
      // -- erreur SQL (ex: BD pas ouverte)
      private void Terminer ()
      {
         if (m_Connexion != null)
         {
            try
            {
               m_Connexion.close ();
            }
            catch (SQLException sqle)
            {
               System.err.println (sqle.getMessage ());
            }
            m_Connexion = null; // pour simplifier la collecte d'ordures
         }
      }

      private Connexion ()
      {
         m_NbUsagers = 0;
         m_ConnexionOuverte = false;
         m_Connexion = null;
         try
         {
            // -- Charger la classe pilote
            Class.forName (CLASSE_PILOTE);
            m_Connexion = DriverManager.getConnection (URI_SOURCE);
            m_ConnexionOuverte = true;
         }
         catch (ClassNotFoundException cnfe)
         {
            System.err.println (cnfe.getMessage ());
         }
         catch (SQLException sqle)
         {
            System.err.println (sqle.getMessage ());
         }
      }
      public boolean EstOuverte () { return m_ConnexionOuverte; }
      public Statement Crernonc() throws SQLException
      {
         return m_Connexion.createStatement ();
      }
   }

   //
   // La connexion
   //
   private Connexion m_Connexion;

   public POQExplorateur_v2 ()
   {
      m_Connexion = Connexion.GetConnexion ();
   }

   public boolean ConnexionOuverte ()
   {
      return m_Connexion.EstOuverte ();
   }
   public void Terminer ()
   {
      m_Connexion.RelcherConnexion();
   }

   // Mthode GetListePropritaires ()
   //
   // Extrait la liste des noms de propritaires, les insre dans
   // un vecteur (tableau dynamique) et retourne ce vecteur
   public Vector GetListePropritaires ()
   {
      final String SQL_LISTE_PROPRITAIRES =
         "Select NomProprio From POQProprio";

      Vector v = new Vector ();
      try
      {
         Statement stmt = m_Connexion.Crernonc ();
         ResultSet results = stmt.executeQuery (SQL_LISTE_PROPRITAIRES);
         while (results.next ())
            v.add (results.getString ("NomProprio"));
         results.close ();
      }
      catch (SQLException sqle)
      {
         System.err.println (sqle.getMessage ());
      }
      return v;
   }


   // Programme principal
   //
   // Ouvre une connexion  la BD; en extrait la liste des propritaires
   // de POQmon (leur nom seulement); affiche cette liste; puis ferme la
   // connexion
   public static void main (String [] args)
   {
      POQExplorateur_v2 pe = new POQExplorateur_v2();
      if (pe.ConnexionOuverte ())
      {
         Vector v = pe.GetListePropritaires ();
         Iterator itt = v.iterator ();
         System.out.println ("Liste des propritaires de POQmon:");
         while (itt.hasNext ())
            System.out.println ((String) itt.next ());
         pe.Terminer ();
      }
   }
}
